@@ -3,7 +3,7 @@
 **
 ** <file/class description>
 **
-** Copyright (C) 2002-2004 Steve Lhomme.  All rights reserved.
+** Copyright (C) 2002-2005 Steve Lhomme.  All rights reserved.
 **
 ** This library is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU Lesser General Public
@@ -48,6 +48,8 @@ START_LIBMATROSKA_NAMESPACE
 
 class KaxCluster;
 class KaxReferenceBlock;
+class KaxInternalBlock;
+class KaxBlockBlob;
 
 class MATROSKA_DLL_API DataBuffer {
 	protected:
@@ -63,6 +65,7 @@ class MATROSKA_DLL_API DataBuffer {
 			,bValidValue(true)	
       ,myFreeBuffer(aFreeBuffer)
 		{}
+		virtual ~DataBuffer() {}
 		virtual binary * Buffer() {return myBuffer;}
 		virtual uint32   & Size() {return mySize;};
 		virtual const binary * Buffer() const {return myBuffer;}
@@ -87,6 +90,7 @@ class MATROSKA_DLL_API SimpleDataBuffer : public DataBuffer {
 			,Offset(aOffset)
 			,BaseBuffer(aBuffer)
 		{}
+		virtual ~SimpleDataBuffer() {}
 
 		DataBuffer * Clone() {return new SimpleDataBuffer(*this);}
 
@@ -143,10 +147,9 @@ class MATROSKA_DLL_API KaxBlockGroup : public EbmlMaster {
 			\brief Addition of a frame with a backward+forward reference (B frame)
 		*/
 		bool AddFrame(const KaxTrackEntry & track, uint64 timecode, DataBuffer & buffer, const KaxBlockGroup & PastBlock, const KaxBlockGroup & ForwBlock, LacingType lacing = LACING_AUTO);
+		bool AddFrame(const KaxTrackEntry & track, uint64 timecode, DataBuffer & buffer, const KaxBlockBlob * PastBlock, const KaxBlockBlob * ForwBlock, LacingType lacing = LACING_AUTO);
 
-		void SetParent(KaxCluster & aParentCluster) {
-			ParentCluster = &aParentCluster;
-		}
+		void SetParent(KaxCluster & aParentCluster);
 
 		void SetParentTrack(const KaxTrackEntry & aParentTrack) {
 			ParentTrack = &aParentTrack;
@@ -182,20 +185,20 @@ class MATROSKA_DLL_API KaxBlockGroup : public EbmlMaster {
 		*/
 		void ReleaseFrames();
 
+		operator KaxInternalBlock &();
+
 	protected:
 		KaxCluster * ParentCluster;
 		const KaxTrackEntry * ParentTrack;
 };
 
-class MATROSKA_DLL_API KaxBlock : public EbmlBinary {
+class KaxInternalBlock : public EbmlBinary {
 	public:
-		KaxBlock() :bLocalTimecodeUsed(false), mLacing(LACING_AUTO), ParentCluster(NULL) {}
-		KaxBlock(const KaxBlock & ElementToClone);
-		~KaxBlock();
-		static EbmlElement & Create() {return *(new KaxBlock);}
-		const EbmlCallbacks & Generic() const {return ClassInfos;}
-		static const EbmlCallbacks ClassInfos;
-		operator const EbmlId &() const {return ClassInfos.GlobalId;}
+		KaxInternalBlock( bool bSimple ) :bLocalTimecodeUsed(false), mLacing(LACING_AUTO), mInvisible(false)
+			,ParentCluster(NULL), bIsSimple(bSimple), bIsKeyframe(true), bIsDiscardable(false)
+		{}
+		KaxInternalBlock(const KaxInternalBlock & ElementToClone);
+		~KaxInternalBlock();
 		bool ValidateSize() const;
 
 		uint16 TrackNum() const {return TrackNumber;}
@@ -219,7 +222,7 @@ class MATROSKA_DLL_API KaxBlock : public EbmlBinary {
 		unsigned int NumberFrames() const { return SizeList.size();}
 		DataBuffer & GetBuffer(unsigned int iIndex) {return *myBuffers[iIndex];}
 
-		bool AddFrame(const KaxTrackEntry & track, uint64 timecode, DataBuffer & buffer, LacingType lacing = LACING_AUTO);
+		bool AddFrame(const KaxTrackEntry & track, uint64 timecode, DataBuffer & buffer, LacingType lacing = LACING_AUTO, bool invisible = false);
 
 		/*!
 			\brief release all the frames of all Blocks
@@ -228,8 +231,6 @@ class MATROSKA_DLL_API KaxBlock : public EbmlBinary {
 
 		void SetParent(KaxCluster & aParentCluster);
 
-		EbmlElement * Clone() const {return new KaxBlock(*this);}
-
 		/*!
 			\return Returns the lacing type that produces the smallest footprint.
 		*/
@@ -248,6 +249,10 @@ class MATROSKA_DLL_API KaxBlock : public EbmlBinary {
 			\note return -1 if the position doesn't exist
 		*/
 		int64 GetFrameSize(size_t FrameNumber = 0);
+		
+		bool IsInvisible() const { return mInvisible; }
+
+		uint64 ClusterPosition() const;
 
 	protected:
 		std::vector<DataBuffer *> myBuffers;
@@ -257,11 +262,90 @@ class MATROSKA_DLL_API KaxBlock : public EbmlBinary {
 		bool       bLocalTimecodeUsed;
 		uint16     TrackNumber;
 		LacingType mLacing;
+		bool       mInvisible;
 		uint64     FirstFrameLocation;
 
 		uint32 RenderData(IOCallback & output, bool bForceRender, bool bSaveDefault = false);
 
 		KaxCluster * ParentCluster;
+		bool       bIsSimple;
+		bool       bIsKeyframe;
+		bool       bIsDiscardable;
+};
+
+class MATROSKA_DLL_API KaxBlock : public KaxInternalBlock {
+	public:
+		KaxBlock() :KaxInternalBlock(false) {}
+		static EbmlElement & Create() {return *(new KaxBlock);}
+		static const EbmlCallbacks ClassInfos;
+		operator const EbmlId &() const {return ClassInfos.GlobalId;}
+		const EbmlCallbacks & Generic() const {return ClassInfos;}
+		EbmlElement * Clone() const {return new KaxBlock(*this);}
+};
+
+#if MATROSKA_VERSION >= 2
+class MATROSKA_DLL_API KaxSimpleBlock : public KaxInternalBlock {
+	public:
+		KaxSimpleBlock() :KaxInternalBlock(true) {}
+		static EbmlElement & Create() {return *(new KaxSimpleBlock);}
+		static const EbmlCallbacks ClassInfos;
+		operator const EbmlId &() const {return ClassInfos.GlobalId;}
+		const EbmlCallbacks & Generic() const {return ClassInfos;}
+		EbmlElement * Clone() const {return new KaxSimpleBlock(*this);}
+
+		void SetKeyframe(bool b_keyframe) { bIsKeyframe = b_keyframe; }
+		void SetDiscardable(bool b_discard) { bIsDiscardable = b_discard; }
+
+		bool IsKeyframe() const    { return bIsKeyframe; }
+		bool IsDiscardable() const { return bIsDiscardable; }
+
+		operator KaxInternalBlock &() { return *this; }
+};
+#endif // MATROSKA_VERSION
+
+class MATROSKA_DLL_API KaxBlockBlob {
+public:
+	KaxBlockBlob(BlockBlobType sblock_mode) :ParentCluster(NULL), SimpleBlockMode(sblock_mode) {
+		bUseSimpleBlock = (sblock_mode != BLOCK_BLOB_NO_SIMPLE);
+		Block.group = NULL;
+	}
+
+	~KaxBlockBlob() {
+#if MATROSKA_VERSION >= 2
+		if (bUseSimpleBlock)
+			delete Block.simpleblock;
+		else
+#endif // MATROSKA_VERSION
+			delete Block.group;
+	}
+
+	operator KaxBlockGroup &();
+#if MATROSKA_VERSION >= 2
+	operator KaxSimpleBlock &();
+#endif
+	operator KaxInternalBlock &();
+	operator const KaxInternalBlock &() const;
+
+	void SetBlockGroup( KaxBlockGroup &BlockRef );
+
+	void SetBlockDuration(uint64 TimeLength);
+
+	void SetParent(KaxCluster & aParentCluster);
+	bool AddFrameAuto(const KaxTrackEntry & track, uint64 timecode, DataBuffer & buffer, LacingType lacing = LACING_AUTO, const KaxBlockBlob * PastBlock = NULL, const KaxBlockBlob * ForwBlock = NULL);
+
+	bool IsSimpleBlock() const {return bUseSimpleBlock;}
+
+	bool ReplaceSimpleByGroup();
+protected:
+	KaxCluster * ParentCluster;
+	union {
+		KaxBlockGroup *group;
+#if MATROSKA_VERSION >= 2
+		KaxSimpleBlock *simpleblock;
+#endif // MATROSKA_VERSION
+	} Block;
+	bool bUseSimpleBlock;
+	BlockBlobType SimpleBlockMode;
 };
 
 class MATROSKA_DLL_API KaxBlockDuration : public EbmlUInteger {
