@@ -29,7 +29,7 @@
 
 /*!
 	\file
-	\version \$Id: KaxTags.cpp,v 1.4 2004/04/14 23:26:18 robux4 Exp $
+	\version \$Id: KaxTags.cpp 711 2004-08-10 12:58:47Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 	\author Jory Stone       <jcsston @ toughguy.net>
 */
@@ -44,7 +44,7 @@ START_LIBMATROSKA_NAMESPACE
 
 EbmlSemantic KaxTags_ContextList[1] =
 {
-	EbmlSemantic(false, false, KaxTag::ClassInfos),
+	EbmlSemantic(true, false, KaxTag::ClassInfos),
 };
 
 const EbmlSemanticContext KaxTags_Context = EbmlSemanticContext(countof(KaxTags_ContextList), KaxTags_ContextList, &KaxSegment_Context, *GetKaxGlobal_Context, &KaxTags::ClassInfos);
