@@ -27,7 +27,7 @@
 
 /*!
     \file
-    \version \$Id: test8.cpp,v 1.9 2004/04/14 23:26:18 robux4 Exp $
+    \version \$Id: test8.cpp 675 2004-07-27 07:56:14Z mosu $
     \brief Test reading of the Header
     \author Steve Lhomme     <robux4 @ users.sf.net>
 */
@@ -273,7 +273,7 @@ int main(int argc, char **argv)
 						} else if (EbmlId(*ElementLevel2) == KaxMuxingApp::ClassInfos.GlobalId) {
 							KaxMuxingApp *pApp = static_cast<KaxMuxingApp*>(ElementLevel2);
 							pApp->ReadData(aStream.I_O());
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__CYGWIN__) && !defined(__APPLE__) && !defined(__BEOS__) && !defined(__NetBSD__)
 							wprintf(L"Muxing App : %ls\n", UTFstring(*pApp).c_str());
 #else
 							printf("Muxing App : %s\n", UTFstring(*pApp).c_str());
@@ -281,7 +281,7 @@ int main(int argc, char **argv)
 						} else if (EbmlId(*ElementLevel2) == KaxWritingApp::ClassInfos.GlobalId) {
 							KaxWritingApp *pApp = static_cast<KaxWritingApp*>(ElementLevel2);
 							pApp->ReadData(aStream.I_O());
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__CYGWIN__) && !defined(__APPLE__) && !defined(__BEOS__) && !defined(__NetBSD__)
 							wprintf(L"Writing App : %ls ()\n", UTFstring(*pApp).c_str());
 #else
 							printf("Writing App : %s ()\n", UTFstring(*pApp).c_str());
@@ -600,7 +600,7 @@ int main(int argc, char **argv)
 											unsigned int Index4;
 											for (Index4 = 0; Index4<aDisplay.ListSize() ;Index4++) {
 												if (aDisplay[Index4]->Generic().GlobalId == KaxChapterString::ClassInfos.GlobalId) {
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__CYGWIN__) && !defined(__APPLE__) && !defined(__BEOS__) && !defined(__NetBSD__)
 													wprintf(L"       Display \"%s\"\n", UTFstring(*static_cast<EbmlUnicodeString *>(aDisplay[Index4])).c_str() );
 #else
 													printf("       Display \"%s\"\n", UTFstring(*static_cast<EbmlUnicodeString *>(aDisplay[Index4])).c_str() );
